@@ -1,6 +1,6 @@
 package Getopt::EX;
 use 5.014;
-use version; our $VERSION = version->declare("2.1.1");
+use version; our $VERSION = version->declare("2.1.2");
 
 1;
 
@@ -11,7 +11,7 @@ Getopt::EX - Getopt Extender
 
 =head1 VERSION
 
-Version 2.1.1
+Version 2.1.2
 
 
 =head1 DESCRIPTION
@@ -121,7 +121,7 @@ specific function at the beginning of execution.  Write something
 like:
 
     use Getopt::EX::Func qw(parse_func);
-    GetOptions("begin:s" => $opt_begin);
+    GetOptions("begin:s" => \my $opt_begin);
     my $func = parse_func($opt_begin);
     $func->call;
 
@@ -239,6 +239,12 @@ before executing command.
 L<Getopt::EX::termcolor> is a common module to manipulate system
 dependent terminal color.
 
+=head2 L<Getopt::EX::RPN>
+
+L<Getopt::EX::RPN> provides a RPN (Reverse Polish Notation)
+calculation interface for command line arguments.  This is convenient
+when you want to define parameter based on terminal height or width.
+
 =head1 AUTHOR
 
 Kazumasa Utashiro
@@ -249,7 +255,7 @@ The following copyright notice applies to all the files provided in
 this distribution, including binary files, unless explicitly noted
 otherwise.
 
-Copyright 2015-2022 Kazumasa Utashiro
+Copyright 2015-2023 Kazumasa Utashiro
 
 =head1 LICENSE
 
@@ -260,4 +266,4 @@ it under the same terms as Perl itself.
 
 #  LocalWords:  Getopt colormap perl foo bar buz colorize BASECLASS
 #  LocalWords:  rc examplerc ENV ARGV getoptions builtins func linux
-#  LocalWords:  GetOptions redhat Kazumasa Utashiro
+#  LocalWords:  GetOptions redhat Kazumasa Utashiro RPN
