@@ -1,5 +1,5 @@
 package Getopt::EX::LabeledParam;
-use version; our $VERSION = version->declare("2.1.1");
+use version; our $VERSION = version->declare("2.1.2");
 
 use v5.14;
 use warnings;
@@ -86,7 +86,7 @@ sub load_params {
     map {
 	my $spec = pop @$_;
 	my @spec;
-	while ($spec =~ s/\&(\w+ (?: \( [^)]* \) )? ) ;?//x) { # &func
+	while ($spec =~ s/\&([:\w]+ (?: \( [^)]* \) )? ) ;?//x) { # &func
 	    push @spec, parse_func({ PACKAGE => 'main' }, $1);
 	}
 	if ($spec =~ s/\b(sub\s*{.*)//) { # sub { ... }
