@@ -1,5 +1,5 @@
 package Getopt::EX::Long;
-use version; our $VERSION = version->declare("2.1.1");
+use version; our $VERSION = version->declare("2.1.2");
 
 use v5.14;
 use warnings;
@@ -238,4 +238,5 @@ Subroutine B<GetOptionsFromString> is not supported.
 =head1 SEE ALSO
 
 L<Getopt::EX>,
-L<Getopt::EX::Module>
+L<Getopt::EX::Module>,
+L<Getopt::EX::Loader>
